@@ -39,12 +39,13 @@ cdbGetDoc <- function(cdb){
                        cdb$DBName,"/",
                        cdb$id,
                        sep="")
-    
+   
     res <- getURL(utils::URLencode(adrString),
                   customrequest = "GET",
                   curl          = cdb$curl,
-                  .opts         = cdb$opts(cdb))
-    
+                  .opts         = cdb$opts(cdb),
+                  .encoding     = cdb$serverEnc
+                  )
 
     return(cdb$checkRes(cdb,res))
 
