@@ -32,7 +32,9 @@ cdbListDB <- function(cdb){
     res <- getURL(utils::URLencode(adrString),
                   customrequest = "GET",
                   curl          = cdb$curl,
-                  .opts         = cdb$opts(cdb))
+                  .opts         = cdb$opts(cdb),
+                  .encoding     = cdb$serverEnc
+                  )
     
     return(cdb$checkRes(cdb,res))
   }else{
